@@ -1,6 +1,6 @@
 /*
  * happydigger - program for cataloging archaeological finds
- * Copyright (C) 2004, 2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2004, 2005, 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
 #include <gtk/gtk.h>
@@ -167,3 +167,33 @@ on_image1entry_changed                 (GtkEditable     *editable,
 void
 on_image2entry_changed                 (GtkEditable     *editable,
                                         gpointer         user_data);
+
+void
+on_webbutton_clicked                   (GtkButton       *button,
+                                        gpointer         user_data);
+
+gboolean
+on_mapchooserdialog_delete_event       (GtkWidget       *widget,
+                                        GdkEvent        *event,
+                                        gpointer         user_data);
+
+void
+on_folder_cancel_button_clicked        (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_folder_open_button_clicked          (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_progresscancelbutton_clicked        (GtkButton       *button,
+                                        gpointer         user_data);
+
+gboolean
+on_startupdialog_delete_event          (GtkWidget       *widget,
+                                        GdkEvent        *event,
+                                        gpointer         user_data);
+
+void
+on_printbutton_clicked                 (GtkButton       *button,
+                                        gpointer         user_data);
