@@ -1,6 +1,6 @@
 /*
  * happydigger - program for cataloging archaeological finds
- * Copyright (C) 2004, 2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2004, 2005, 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,13 +14,13 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
 #include <gtk/gtk.h>
 #include <stdlib.h>
 #include "callbacks.h"
-#include "support.h"
+#include "utils.h"
 #include "preferences.h"
 #include "gui_utils.h"
 #include "db.h"
@@ -28,6 +28,23 @@
 extern GtkWidget *window;
 extern preferencestype preferences;
 
+static gchar *
+my_strreplace(const char *str, const char *delimiter, const char *replacement)
+{
+	gchar **split;
+	gchar *ret;
+
+	g_return_val_if_fail (str != NULL, NULL);
+	g_return_val_if_fail (delimiter != NULL, NULL);
+	g_return_val_if_fail (replacement != NULL, NULL);
+
+	split = g_strsplit (str, delimiter, 0);
+	ret = g_strjoinv (replacement, split);
+	g_strfreev (split);
+
+	return ret;
+}
+
 gboolean
 on_preferencesdialog_delete_event      (GtkWidget       *widget,
                                         GdkEvent        *event,
@@ -51,8 +68,12 @@ void
 on_preferencesokbutton_clicked         (GtkButton       *button,
                                         gpointer         user_data)
 {
-	GtkWidget *preferencesdialog, *ptypesentry, *pmaterialsentry, *pperiodsentry;
-	GtkWidget *p1, *p2, *p3, *p4, *p5, *p6, *p7, *p8, *p9, *p10, *p11, *p12, *p13, *p14, *p15;
+	GtkWidget *preferencesdialog, *typestextview, *materialstextview,
+		*periodstextview;
+	GtkWidget *p1, *p2, *p3, *p4, *p5, *p6, *p7, *p8, *p9, *p10, *p11, *p12,
+		*p13, *p14, *p15;
+	GtkTextBuffer *buffer;
+	GtkTextIter start, end;
 	gboolean check;
 	gchar **states;
 	gint i;
@@ -62,13 +83,26 @@ on_preferencesokbutton_clicked         (GtkButton       *button,
 	
 
 	preferencesdialog = gtk_widget_get_toplevel (GTK_WIDGET(button));
-	ptypesentry = lookup_widget (preferencesdialog, "ptypesentry");
-	pmaterialsentry = lookup_widget (preferencesdialog, "pmaterialsentry");
-	pperiodsentry = lookup_widget (preferencesdialog, "pperiodsentry");
 
-	preferences.types = gtk_editable_get_chars (GTK_EDITABLE (ptypesentry), 0, -1);
-	preferences.materials = gtk_editable_get_chars (GTK_EDITABLE (pmaterialsentry), 0, -1);
-	preferences.periods = gtk_editable_get_chars (GTK_EDITABLE (pperiodsentry), 0, -1);
+	typestextview = lookup_widget (preferencesdialog, "typestextview");
+	materialstextview = lookup_widget (preferencesdialog, "materialstextview");
+	periodstextview = lookup_widget (preferencesdialog, "periodstextview");
+	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (typestextview));
+	gtk_text_buffer_get_start_iter (buffer, &start);
+	gtk_text_buffer_get_end_iter (buffer, &end);
+	preferences.types = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
+	preferences.types = my_strreplace (preferences.types, "\n", " ");
+	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (materialstextview));
+	gtk_text_buffer_get_start_iter (buffer, &start);
+	gtk_text_buffer_get_end_iter (buffer, &end);
+	preferences.materials = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
+	preferences.materials = my_strreplace (preferences.materials, "\n", " ");
+	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (periodstextview));
+	gtk_text_buffer_get_start_iter (buffer, &start);
+	gtk_text_buffer_get_end_iter (buffer, &end);
+	preferences.periods = gtk_text_buffer_get_text (buffer, &start, &end, TRUE);
+	preferences.periods = my_strreplace (preferences.periods, "\n", " ");
+
 	set_combostrings ();
 
 	/* refresh the combostrings */
