@@ -536,10 +536,6 @@ on_helpbutton_clicked                  (GtkButton       *button,
 	gtk_widget_show (helpwindow);
 }
 
-#define GLADE_HOOKUP_OBJECT(component,widget,name) \
-  g_object_set_data_full (G_OBJECT (component), name, \
-    gtk_widget_ref (widget), (GDestroyNotify) gtk_widget_unref)
-
 static void
 on_reverse_toggled (GtkToggleButton *togglebutton, gpointer user_data)
 {
