@@ -1,6 +1,6 @@
 /*
  * happydigger - program for cataloging archaeological finds
- * Copyright (C) 2004, 2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2004, 2005, 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
  /* functions for creating tables and adding, removing and updating records */
@@ -22,7 +22,7 @@
 #include <gtk/gtk.h>
 #include <stdlib.h>
 #include "db.h"
-#include "support.h"
+#include "utils.h"
 #include "preferences.h"
 
 extern sqlite3 *db;
@@ -64,7 +64,7 @@ create_db (gchar *name)
 		"type varchar (80),"
 		"material varchar (80),"
 		"period varchar (80),"
-		"notes varchar (220),"
+		"notes varchar (500),"
 		"date varchar (80),"
 		"value varchar (80),"
 		"reference varchar (80),"
@@ -72,10 +72,10 @@ create_db (gchar *name)
 		"finddate varchar (80),"
 		"location varchar (80),"
 		"coordinates varchar (80),"
-		"spotnotes varchar (220),"
+		"spotnotes varchar (500),"
 
-		"image1 varchar (80),"
-		"image2 varchar (80)"
+		"image1 varchar (200),"
+		"image2 varchar (200)"
 		");", name);
 	ret = sqlite3_exec (db, query, NULL, &records, &err);
 	return ret;
