@@ -24,10 +24,6 @@
 extern GtkWidget *window;
 extern preferencestype preferences;
 
-#define GLADE_HOOKUP_OBJECT(component,widget,name) \
-  g_object_set_data_full (G_OBJECT (component), name, \
-    gtk_widget_ref (widget), (GDestroyNotify) gtk_widget_unref)
-
 void
 preview_update (GtkFileChooser *chooser, gpointer data)
 {
