@@ -32,7 +32,7 @@
 
 #define GLADE_HOOKUP_OBJECT(component,widget,name) \
   g_object_set_data_full (G_OBJECT (component), name, \
-    gtk_widget_ref (widget), (GDestroyNotify) gtk_widget_unref)
+    g_object_ref (widget), (GDestroyNotify) g_object_unref)
 
 #define GLADE_HOOKUP_OBJECT_NO_REF(component,widget,name) \
   g_object_set_data (G_OBJECT (component), name, widget)
@@ -145,9 +145,6 @@ create_window (void)
   GtkWidget *imagebutton2;
   GtkWidget *label1;
   GtkAccelGroup *accel_group;
-  GtkTooltips *tooltips;
-
-  tooltips = gtk_tooltips_new ();
 
   accel_group = gtk_accel_group_new ();
 
@@ -177,7 +174,7 @@ create_window (void)
   gtk_widget_show (firstbutton);
   gtk_box_pack_start (GTK_BOX (hbox2), firstbutton, TRUE, TRUE, 0);
   GTK_WIDGET_UNSET_FLAGS (firstbutton, GTK_CAN_FOCUS);
-  gtk_tooltips_set_tip (tooltips, firstbutton, _("First [Ctrl-Up]"), NULL);
+  gtk_widget_set_tooltip_text (firstbutton, _("First [Ctrl-Up]"));
   gtk_widget_add_accelerator (firstbutton, "clicked", accel_group,
                               GDK_Up, (GdkModifierType) GDK_CONTROL_MASK,
                               GTK_ACCEL_VISIBLE);
@@ -190,7 +187,7 @@ create_window (void)
   gtk_widget_show (rewindbutton);
   gtk_box_pack_start (GTK_BOX (hbox2), rewindbutton, TRUE, TRUE, 0);
   GTK_WIDGET_UNSET_FLAGS (rewindbutton, GTK_CAN_FOCUS);
-  gtk_tooltips_set_tip (tooltips, rewindbutton, _("-5 [Ctrl-Shift-Left]"), NULL);
+  gtk_widget_set_tooltip_text (rewindbutton, _("-5 [Ctrl-Shift-Left]"));
   gtk_widget_add_accelerator (rewindbutton, "clicked", accel_group,
                               GDK_Left, (GdkModifierType) GDK_CONTROL_MASK | GDK_SHIFT_MASK,
                               GTK_ACCEL_VISIBLE);
@@ -211,7 +208,7 @@ create_window (void)
   gtk_widget_show (previousbutton);
   gtk_box_pack_start (GTK_BOX (hbox2), previousbutton, TRUE, TRUE, 0);
   GTK_WIDGET_UNSET_FLAGS (previousbutton, GTK_CAN_FOCUS);
-  gtk_tooltips_set_tip (tooltips, previousbutton, _("Previous [Ctrl-Left]"), NULL);
+  gtk_widget_set_tooltip_text (previousbutton, _("Previous [Ctrl-Left]"));
   gtk_widget_add_accelerator (previousbutton, "clicked", accel_group,
                               GDK_Left, (GdkModifierType) GDK_CONTROL_MASK,
                               GTK_ACCEL_VISIBLE);
@@ -237,7 +234,7 @@ create_window (void)
   gtk_widget_show (nextbutton);
   gtk_box_pack_start (GTK_BOX (hbox2), nextbutton, TRUE, TRUE, 0);
   GTK_WIDGET_UNSET_FLAGS (nextbutton, GTK_CAN_FOCUS);
-  gtk_tooltips_set_tip (tooltips, nextbutton, _("Next [Ctrl-Right]"), NULL);
+  gtk_widget_set_tooltip_text (nextbutton, _("Next [Ctrl-Right]"));
   gtk_widget_add_accelerator (nextbutton, "clicked", accel_group,
                               GDK_Right, (GdkModifierType) GDK_CONTROL_MASK,
                               GTK_ACCEL_VISIBLE);
@@ -249,7 +246,7 @@ create_window (void)
   ffbutton = gtk_button_new ();
   gtk_widget_show (ffbutton);
   gtk_box_pack_start (GTK_BOX (hbox2), ffbutton, TRUE, TRUE, 0);
-  gtk_tooltips_set_tip (tooltips, ffbutton, _("+5 [Ctrl-Shift-Right]"), NULL);
+  gtk_widget_set_tooltip_text (ffbutton, _("+5 [Ctrl-Shift-Right]"));
   gtk_widget_add_accelerator (ffbutton, "clicked", accel_group,
                               GDK_Right, (GdkModifierType) GDK_CONTROL_MASK | GDK_SHIFT_MASK,
                               GTK_ACCEL_VISIBLE);
@@ -269,7 +266,7 @@ create_window (void)
   lastbutton = gtk_button_new ();
   gtk_widget_show (lastbutton);
   gtk_box_pack_start (GTK_BOX (hbox2), lastbutton, TRUE, TRUE, 0);
-  gtk_tooltips_set_tip (tooltips, lastbutton, _("Last [Ctrl-Down]"), NULL);
+  gtk_widget_set_tooltip_text (lastbutton, _("Last [Ctrl-Down]"));
   gtk_widget_add_accelerator (lastbutton, "clicked", accel_group,
                               GDK_Down, (GdkModifierType) GDK_CONTROL_MASK,
                               GTK_ACCEL_VISIBLE);
@@ -286,7 +283,7 @@ create_window (void)
   gtk_widget_show (applybutton);
   gtk_box_pack_start (GTK_BOX (hbox2), applybutton, TRUE, TRUE, 0);
   GTK_WIDGET_UNSET_FLAGS (applybutton, GTK_CAN_FOCUS);
-  gtk_tooltips_set_tip (tooltips, applybutton, _("Update changes [Ctrl-u]"), NULL);
+  gtk_widget_set_tooltip_text (applybutton, _("Update changes [Ctrl-u]"));
   gtk_widget_add_accelerator (applybutton, "clicked", accel_group,
                               GDK_u, (GdkModifierType) GDK_CONTROL_MASK,
                               GTK_ACCEL_VISIBLE);
@@ -299,7 +296,7 @@ create_window (void)
   gtk_widget_show (removebutton);
   gtk_box_pack_start (GTK_BOX (hbox2), removebutton, TRUE, TRUE, 0);
   GTK_WIDGET_UNSET_FLAGS (removebutton, GTK_CAN_FOCUS);
-  gtk_tooltips_set_tip (tooltips, removebutton, _("Delete record [Ctrl-d]"), NULL);
+  gtk_widget_set_tooltip_text (removebutton, _("Delete record [Ctrl-d]"));
   gtk_widget_add_accelerator (removebutton, "clicked", accel_group,
                               GDK_d, (GdkModifierType) GDK_CONTROL_MASK,
                               GTK_ACCEL_VISIBLE);
@@ -312,7 +309,7 @@ create_window (void)
   gtk_widget_show (newbutton);
   gtk_box_pack_start (GTK_BOX (hbox2), newbutton, TRUE, TRUE, 0);
   GTK_WIDGET_UNSET_FLAGS (newbutton, GTK_CAN_FOCUS);
-  gtk_tooltips_set_tip (tooltips, newbutton, _("New record [Ctrl-n]"), NULL);
+  gtk_widget_set_tooltip_text (newbutton, _("New record [Ctrl-n]"));
   gtk_widget_add_accelerator (newbutton, "clicked", accel_group,
                               GDK_n, (GdkModifierType) GDK_CONTROL_MASK,
                               GTK_ACCEL_VISIBLE);
@@ -329,7 +326,7 @@ create_window (void)
   gtk_widget_show (listbutton);
   gtk_box_pack_start (GTK_BOX (hbox2), listbutton, TRUE, TRUE, 0);
   GTK_WIDGET_UNSET_FLAGS (listbutton, GTK_CAN_FOCUS);
-  gtk_tooltips_set_tip (tooltips, listbutton, _("List view [Ctrl-l]"), NULL);
+  gtk_widget_set_tooltip_text (listbutton, _("List view [Ctrl-l]"));
   gtk_widget_add_accelerator (listbutton, "clicked", accel_group,
                               GDK_l, (GdkModifierType) GDK_CONTROL_MASK,
                               GTK_ACCEL_VISIBLE);
@@ -342,7 +339,7 @@ create_window (void)
   gtk_widget_show (webbutton);
   gtk_box_pack_start (GTK_BOX (hbox2), webbutton, TRUE, TRUE, 0);
   GTK_WIDGET_UNSET_FLAGS (webbutton, GTK_CAN_FOCUS);
-  gtk_tooltips_set_tip (tooltips, webbutton, _("Webalbum [Ctrl-w]"), NULL);
+  gtk_widget_set_tooltip_text (webbutton, _("Webalbum [Ctrl-w]"));
   gtk_widget_add_accelerator (webbutton, "clicked", accel_group,
                               GDK_w, (GdkModifierType) GDK_CONTROL_MASK,
                               GTK_ACCEL_VISIBLE);
@@ -355,7 +352,7 @@ create_window (void)
   gtk_widget_show (printbutton);
   gtk_box_pack_start (GTK_BOX (hbox2), printbutton, TRUE, TRUE, 0);
   GTK_WIDGET_UNSET_FLAGS (printbutton, GTK_CAN_FOCUS);
-  gtk_tooltips_set_tip (tooltips, printbutton, _("Print [Ctrl-p]"), NULL);
+  gtk_widget_set_tooltip_text (printbutton, _("Print [Ctrl-p]"));
   gtk_widget_add_accelerator (printbutton, "clicked", accel_group,
                               GDK_p, (GdkModifierType) GDK_CONTROL_MASK,
                               GTK_ACCEL_VISIBLE);
@@ -368,7 +365,7 @@ create_window (void)
   gtk_widget_show (prefsbutton);
   gtk_box_pack_start (GTK_BOX (hbox2), prefsbutton, TRUE, TRUE, 0);
   GTK_WIDGET_UNSET_FLAGS (prefsbutton, GTK_CAN_FOCUS);
-  gtk_tooltips_set_tip (tooltips, prefsbutton, _("Settings [Ctrl-e]"), NULL);
+  gtk_widget_set_tooltip_text (prefsbutton, _("Settings [Ctrl-e]"));
   gtk_widget_add_accelerator (prefsbutton, "clicked", accel_group,
                               GDK_e, (GdkModifierType) GDK_CONTROL_MASK,
                               GTK_ACCEL_VISIBLE);
@@ -381,7 +378,7 @@ create_window (void)
   gtk_widget_show (helpbutton);
   gtk_box_pack_start (GTK_BOX (hbox2), helpbutton, TRUE, TRUE, 0);
   GTK_WIDGET_UNSET_FLAGS (helpbutton, GTK_CAN_FOCUS);
-  gtk_tooltips_set_tip (tooltips, helpbutton, _("Help [Ctrl-h]"), NULL);
+  gtk_widget_set_tooltip_text (helpbutton, _("Help [Ctrl-h]"));
   gtk_widget_add_accelerator (helpbutton, "clicked", accel_group,
                               GDK_h, (GdkModifierType) GDK_CONTROL_MASK,
                               GTK_ACCEL_VISIBLE);
@@ -670,7 +667,7 @@ create_window (void)
   gtk_widget_show (image1button);
   gtk_box_pack_start (GTK_BOX (hbox17), image1button, FALSE, FALSE, 0);
 //  gtk_widget_set_size_request (image1button, -1, 27);
-  gtk_tooltips_set_tip (tooltips, image1button, _("Select first image"), NULL);
+  gtk_widget_set_tooltip_text (image1button, _("Select first image"));
 
   image24 = gtk_image_new_from_stock ("gtk-open", GTK_ICON_SIZE_BUTTON);
   gtk_widget_show (image24);
@@ -689,7 +686,7 @@ create_window (void)
   gtk_widget_show (image2button);
   gtk_box_pack_start (GTK_BOX (hbox18), image2button, FALSE, FALSE, 0);
 //  gtk_widget_set_size_request (image2button, -1, 27);
-  gtk_tooltips_set_tip (tooltips, image2button, _("Select second image"), NULL);
+  gtk_widget_set_tooltip_text (image2button, _("Select second image"));
 
   image25 = gtk_image_new_from_stock ("gtk-open", GTK_ICON_SIZE_BUTTON);
   gtk_widget_show (image25);
@@ -702,7 +699,7 @@ create_window (void)
   imagebutton1 = gtk_button_new ();
   gtk_widget_show (imagebutton1);
   gtk_box_pack_start (GTK_BOX (hbox19), imagebutton1, FALSE, FALSE, 0);
-  gtk_tooltips_set_tip (tooltips, imagebutton1, _("Show first image [Ctrl-1]"), NULL);
+  gtk_widget_set_tooltip_text (imagebutton1, _("Show first image [Ctrl-1]"));
   gtk_widget_add_accelerator (imagebutton1, "clicked", accel_group,
                               GDK_1, (GdkModifierType) GDK_CONTROL_MASK,
                               GTK_ACCEL_VISIBLE);
@@ -711,7 +708,7 @@ create_window (void)
   imagebutton2 = gtk_button_new_with_mnemonic ("");
   gtk_widget_show (imagebutton2);
   gtk_box_pack_start (GTK_BOX (hbox19), imagebutton2, FALSE, FALSE, 0);
-  gtk_tooltips_set_tip (tooltips, imagebutton2, _("Show second image [Ctrl-2]"), NULL);
+  gtk_widget_set_tooltip_text (imagebutton2, _("Show second image [Ctrl-2]"));
   gtk_widget_add_accelerator (imagebutton2, "clicked", accel_group,
                               GDK_2, (GdkModifierType) GDK_CONTROL_MASK,
                               GTK_ACCEL_VISIBLE);
@@ -900,7 +897,6 @@ create_window (void)
   GLADE_HOOKUP_OBJECT (window, imagebutton1, "imagebutton1");
   GLADE_HOOKUP_OBJECT (window, imagebutton2, "imagebutton2");
   GLADE_HOOKUP_OBJECT (window, label1, "label1");
-  GLADE_HOOKUP_OBJECT_NO_REF (window, tooltips, "tooltips");
 
   gtk_window_add_accel_group (GTK_WINDOW (window), accel_group);
 
