@@ -1,6 +1,6 @@
 /*
  * happydigger - program for cataloging archaeological finds
- * Copyright (C) 2004, 2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2004, 2005, 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
 typedef struct
@@ -23,12 +23,19 @@ typedef struct
   gchar *materials;
   gchar *periods;
   gchar *colvisible;
+  gchar *webpagetitle;
+  gchar *webpagefootnote;
+  gint reverseorder;
+  gint recordsperpage;
+  gint sortby;
 } preferencestype;
 
 typedef struct
 {
   gchar *imageloaddir; /* last images loaded from this directory */
   gchar *table;        /* name of the table used */
+  gchar *webmapdir;    /* last html export to this directory */
+  gchar *sortby;       /* name to sort by when exporting to html */
 } statestype;
 
 void loadpreferences (void);
